@@ -1378,11 +1378,9 @@ short UDrawChar(u_char code, short styles, short ffont, int groupheight, int pas
 
 /*----------------------------------------------------------------------*/
 /* Draw an entire string, including parameter substitutions		*/
-/* (Normally called as UDrawString(); see below)			*/
 /*----------------------------------------------------------------------*/
 
-void UDrawString0(labelptr drawlabel, int passcolor, objinstptr localinst,
-	Boolean drawX)
+void UDrawString(labelptr drawlabel, int passcolor, objinstptr localinst)
 {
    stringpart *strptr;
    char *textptr;
@@ -1649,7 +1647,7 @@ void UDrawString0(labelptr drawlabel, int passcolor, objinstptr localinst,
 
    UPopCTM();
 
-   if (drawX && drawlabel->pin) UDrawXDown(drawlabel);
+   if (drawlabel->pin) UDrawXDown(drawlabel);
 
    if ((defaultcolor != DOFORALL) && (passcolor != curcolor)) {
       XTopSetForeground(passcolor);
@@ -1658,24 +1656,6 @@ void UDrawString0(labelptr drawlabel, int passcolor, objinstptr localinst,
    xobjs.pagelist[areawin->page]->wirewidth = tmpthick;
 }
 
-/*----------------------------------------------------------------------*/
-/* Draw String, with an "x" mark at the origin				*/
-/*----------------------------------------------------------------------*/
-
-void UDrawString(labelptr drawlabel, int passcolor, objinstptr localinst)
-{
-   UDrawString0(drawlabel, passcolor, localinst, TRUE);
-}
-
-/*----------------------------------------------------------------------*/
-/* Draw String, without the "x" mark					*/
-/*----------------------------------------------------------------------*/
-
-void UDrawStringNoX(labelptr drawlabel, int passcolor, objinstptr localinst)
-{
-   UDrawString0(drawlabel, passcolor, localinst, FALSE);
-}
-
 /*----------------------------------------------------------------------*/
 /* Compute the actual length of a string or portion thereof.		*/
 /*----------------------------------------------------------------------*/
